@@ -1,18 +1,12 @@
 #!/usr/bin/env python3
-# coding: UTF-8
-#
-# Copyright © 2012, Elizabeth J. Myers, et al. All rights reserved.
-# License terms can be found in the LICENSE file at the top level of the source
-# tree.
 
 from __future__ import unicode_literals, print_function
 
 from sys import path, stderr
 import os
 import socket
-from PyProto.eventloop import EventLoop, Events
-from PyProto.splitter import LineSplitter
-from PyProto.utils import Printer
+from PyProto.eventloop import EventLoop, util as evutil
+from PyProto.splitter import LineSplitter, util as splitutil
 
 try:
     import gc
@@ -22,7 +16,7 @@ except Exception as e:
     gc = None
 
 class IRCProtocol(LineSplitter.LineSplitter):
-    @Printer.print_lines
+    @splitutil.print_lines
     def read_line(self, line):
         rawline = line
         # Blow away
